from setuptools import setup, find_packages

setup(
    name="GriffinX",
    version="0.8",
    packages=find_packages(),
    install_requires=[
        # List your project's dependencies here.
        # For example: 'numpy>=1.18.1'
        "torch",
        "numpy",
        "ultralytics",
        "opencv-python>=4.9.0.80",
        "pillow>=10.2.0"
        #"PIL>=7.1.2",
    ],
    # Metadata
    author="Percom@UMD",
    author_email="kirandav@umich.edu",
    description="GriffinX is a middleware package for real time event detection",
    long_description=open('README.md').read(),
    long_description_content_type='text/markdown',  # This is important for making the README render correctly on PyPI
    url="https://github.com/kiran-collab/Griffin-Drone-Car-Collaboration",
    license="MIT",
    classifiers=[
        # Trove classifiers
        # Full list: https://pypi.org/classifiers/
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
    ],
)


import torch
import os
import cv2

def initialize_yolov8():
    print("hellov8!!!!!")
    model_yolov8 = YOLO('yolov8n.pt')

def detect_and_save_cars_v8(partition, output_folder):
    # Detect cars using YOLOv8
    print("hellov8 detect!")
    results = model_yolov8(partition.copy())  # copy of the partition to avoid altering 

    for r in results.pred:
        boxes = r['boxes']
        for box in boxes:
            left, top, right, bottom = map(int, box[:4])

        # Draw rectangle and label on the frame
            cv2.rectangle(partition, (left, top), (right, bottom), (0, 255, 0), 2) 
            label = model_yolov8.names[int(box[5])]
            confidence = float(box[4])
            text = f"{label} {confidence:.2f}"
            cv2.putText(partition, text, (left, bottom + 20), cv2.FONT_HERSHEY_SIMPLEX, 0.6, (0, 255, 0), 1, cv2.LINE_AA) 

# Save the partition with detected cars
    cv2.imwrite(os.path.join(output_folder, f"partition_{selected_partition_index}_yolov8.jpg"), partition)


import torch
import os
import cv2

def initialize_yolov5():
    print("hello!!!!")
    model_yolov5 = torch.hub.load("ultralytics/yolov5:v6.0", "yolov5s", pretrained=True)
    model_yolov5.eval()

def detect_and_save_cars(partition, output_folder, conf_threshold=0.5):
    # Detect cars using YOLOv5
    print("hello detect!")
    results = model_yolov5(partition)

    # Filter bounding boxes based on confidence threshold
    mask = results.xyxy[0][:, 4] >= conf_threshold
    boxes = results.xyxy[0][mask, :4]

    # Draw bounding boxes around detected cars
    for box in boxes:
        x1, y1, x2, y2 = map(int, box)
        cv2.rectangle(partition, (x1, y1), (x2, y2), (0, 255, 0), 2)

    # Save the partition with detected cars
    cv2.imwrite(os.path.join(output_folder, f"partition_{selected_partition_index}_yolov5.jpg"), partition)